==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LocalityLoadBalancerSettingDistributeBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LocalityLoadBalancerSettingDistributeBuilder extends LocalityLoadBalancerSettingDistributeFluentImpl<LocalityLoadBalancerSettingDistributeBuilder> implements VisitableBuilder<LocalityLoadBalancerSettingDistribute,LocalityLoadBalancerSettingDistributeBuilder>{
  public LocalityLoadBalancerSettingDistributeBuilder() {
    this(false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(Boolean validationEnabled) {
    this(new LocalityLoadBalancerSettingDistribute(), validationEnabled);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent) {
    this(fluent, false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LocalityLoadBalancerSettingDistribute(), validationEnabled);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent,LocalityLoadBalancerSettingDistribute instance) {
    this(fluent, instance, false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent,LocalityLoadBalancerSettingDistribute instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistribute instance) {
    this(instance,false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistribute instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  LocalityLoadBalancerSettingDistributeFluent<?> fluent;
  Boolean validationEnabled;
  public LocalityLoadBalancerSettingDistribute build() {
    LocalityLoadBalancerSettingDistribute buildable = new LocalityLoadBalancerSettingDistribute(fluent.getFrom(),fluent.getTo());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LocalityLoadBalancerSettingDistributeBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LocalityLoadBalancerSettingDistributeBuilder extends LocalityLoadBalancerSettingDistributeFluent<LocalityLoadBalancerSettingDistributeBuilder> implements VisitableBuilder<LocalityLoadBalancerSettingDistribute,LocalityLoadBalancerSettingDistributeBuilder>{
  public LocalityLoadBalancerSettingDistributeBuilder() {
    this(false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(Boolean validationEnabled) {
    this(new LocalityLoadBalancerSettingDistribute(), validationEnabled);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent) {
    this(fluent, false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LocalityLoadBalancerSettingDistribute(), validationEnabled);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent,LocalityLoadBalancerSettingDistribute instance) {
    this(fluent, instance, false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistributeFluent<?> fluent,LocalityLoadBalancerSettingDistribute instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LocalityLoadBalancerSettingDistribute());

    if (instance != null) {
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
      fluent.withFrom(instance.getFrom());
      fluent.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistribute instance) {
    this(instance,false);
  }
  public LocalityLoadBalancerSettingDistributeBuilder(LocalityLoadBalancerSettingDistribute instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LocalityLoadBalancerSettingDistribute());

    if (instance != null) {
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
      this.withFrom(instance.getFrom());
      this.withTo(instance.getTo());
    }
    this.validationEnabled = validationEnabled; 
  }
  LocalityLoadBalancerSettingDistributeFluent<?> fluent;
  Boolean validationEnabled;
  public LocalityLoadBalancerSettingDistribute build() {
    LocalityLoadBalancerSettingDistribute buildable = new LocalityLoadBalancerSettingDistribute(fluent.getFrom(),fluent.getTo());
    return buildable;
  }
  
}
